@@ -3,14 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute the TF-IDF measure for ngram phrases
 
-our $VERSION = '0.02';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
 use namespace::clean;
 
 use Carp;
-use Encode;
 use Lingua::EN::Ngram;
 use Lingua::StopWords qw( getStopWords );
 use List::Util qw( sum0 );
@@ -146,22 +145,22 @@ Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
 
 =head1 VERSION
 
-version 0.02
+version 0.0201
 
 =head1 SYNOPSIS
 
   use Text::TFIDF::Ngram;
-  my @files = [qw( foo.txt bar.txt )];
-  my $obj   = Text::TFIDF::Ngram->new(
-    files     => \@files,
+  my $obj = Text::TFIDF::Ngram->new(
+    files     => [qw( foo.txt bar.txt )],
     size      => 3,
     stopwords => 1,
   );
-  my $x = $obj->tf( 'foo.txt', 'foo' );
-  $x = $obj->idf('foo');
-  $x = $obj->tfidf( 'foo.txt', 'foo' );
-  $x = $obj->tfidf_by_file;
-  print Dumper $x;
+  my $w = $obj->tf( 'foo.txt', 'foo' );
+  my $x = $obj->idf('foo');
+  my $y = $obj->tfidf( 'foo.txt', 'foo' );
+  printf "TF: %.3f, IDF: %.3f, TFIDF: %.3f\n", $w, $x, $y;
+  my $z = $obj->tfidf_by_file;
+  print Dumper $z;
 
 =head1 DESCRIPTION
 
@@ -169,10 +168,6 @@ The TF-IDF ("term frequency-inverse document frequency") measure is used in
 information retrieval and text mining.  It is a statistical measure used to see
 how important a word is in a document or collection of documents.
 
-=head1 NAME
-
-Text::TFIDF::Ngram - Compute the TF-IDF measure for ngram phrases
-
 =head1 ATTRIBUTES
 
 =head2 files
@@ -189,7 +184,8 @@ Boolean indicating that phrases with stopwords will be ignored.  Default is 1.
 
 =head2 counts
 
-HashRef of the ngram counts of each processed file.
+HashRef of the ngram counts of each processed file.  This is a computed
+attribute - providing it in the constructor will be ignored.
 
 =head1 METHODS
 
@@ -228,14 +224,14 @@ Returns the inverse document frequency of a B<phrase>.
 
   $tfidf = $obj->tfidf( $file, $phrase );
 
-Computes the TF-IDF weight for the given document and word.  If the file is not
-in the corpus used to populate the module, undef is returned.
+Computes the TF-IDF weight for the given B<file> and B<phrase>.  If the phrase
+is not in the corpus, a warning is issued and undef is returned.
 
 =head2 tfidf_by_file()
 
   $tfidf = $obj->tfidf_by_file;
 
-Construct a HashRef of all files with all terms and their B<tfidf> values.
+Construct a HashRef of all files with all phrases and their B<tfidf> values.
 
 =head1 SEE ALSO
 
